class PurseType(object):
    TYPE_WEBMONEY = 'WebMoney'          # WebMoney
    TYPE_YANDEX_MONEY = 'Yandex'        # Яндекс.Деньги
    TYPE_QIWI = 'QIWI'                  # QIWI
    TYPE_QIWI_SE = 'QIWI_SE'            # QIWI карты самозанятых
    TYPE_ZALEY_CASH = 'ZaleyCash'       # ZaleyCash
    TYPE_RU_CARD = 'RUCARD'             # Банковская карта РФ
    TYPE_WORLD_CARD = 'WORLDCARD'       # Банковская карта Mastercard Worldwide
    TYPE_SNG_CARD = 'SNGCARD'           # Банковская карта MasterCard СНГ USD
    TYPE_KZ_CARD = 'KZCARD'             # Банковская карта Казахстана
    TYPE_UKR_CARD = 'UKRCARD'           # Банковская карта Украины
    TYPE_MTS = 'MTS'                    # MTS
    TYPE_BEELINE = 'Beeline'            # Билайн
    TYPE_MEGAFON = 'MegaFon'            # Мегафон
    TYPE_TELE2 = 'Tele2'                # Tele2
    TYPE_CAPITALIST = 'Capitalist'      # Capitalist
    TYPE_USDTTRC20 = 'USDTTRC20'        # USDT (Tron)
    TYPE_USDTERC20 = 'USDTERC20'        # USDT (Etherium)
    TYPE_PAYTM = 'PAYTM'                # PayTM
    TYPE_IMPS = 'IMPS'                  # IMPS


class Currency(object):
    RUB = 'RUB'
    USD = 'USD'
    EURO = 'EUR'
    INR = 'INR'
