from .utils import create_payment

__title__ = 'Django Master Pay'
__version__ = "1.0.7"
__author__ = 'KokocGroup'
__license__ = 'BSD 2-Clause'

VERSION = __version__

default_app_config = 'django_master_pay.apps.DjangoMasterPayConfig'
