# Generated by Django 2.2.2 on 2021-07-19 15:17

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Payment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Создан')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Обновлен')),
                ('external_id', models.CharField(max_length=250, verbose_name='Внешний ключ')),
                ('master_pay_id', models.CharField(max_length=250, verbose_name='Индефикатор MasterPay')),
                ('status', models.CharField(choices=[('NEW', 'Новый'), ('IN_WORK', 'В работе'), ('DONE', 'Проведен'), ('ERROR', 'Ошибка')], default='NEW', max_length=100, verbose_name='Статус')),
                ('record_data', django.contrib.postgres.fields.jsonb.JSONField(verbose_name='RAW data')),
            ],
            options={
                'verbose_name': 'Платеж',
                'verbose_name_plural': 'Платежи',
            },
        ),
    ]
